<?php
// $Id$

/**
 * @file
 * Theme Functions
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */

/**
 * Implements HOOK_theme().
 *
function om_theme(&$existing, $type, $theme, $path) {
  //drupal_set_message("<pre>" . print_r($existing,true) . "</pre>");

  if ($type == 'theme') {
    dsm($existing, true);
  }
  return array();
}
*/

/**
 * Implements HOOK_theme().
 */
function om_theme() {
  return array(
    'region' => array( /* @Legacy - soon will be deleted */
      'arguments' => array('region_name' => NULL, 'region' => NULL, 'region_classes' => NULL, 'region_inner' => 0),
    ),
    'identity' => array(
      'arguments' => array('logo' => NULL, 'site_name' => NULL, 'site_slogan' => NULL, 'front_page' => NULL),
    ),
    'content_elements' => array(
      'arguments' => array('mission' => NULL, 'tabs' => NULL, 'title' => NULL),
    ),    
    'search_box' => array(
      'arguments' => array('search_box' => NULL),
    ),  
    'menu' => array(
      'arguments' => array('menu_name' => NULL, 'menu' => NULL, 'menu_tree' => NULL),
    ),              
  );
}

/** 
 * Logo, Site Name, Site Slogan
 */
function om_identity($logo, $site_name, $site_slogan, $front_page) {
  if (!empty($logo) || !empty($site_name) || !empty($site_slogan)) { 
    $out = '<div id="logo-title">';
    if (!empty($logo)) $out .= '<a href="' . $front_page . '" title="' . t('Home') . '" rel="home" id="logo"><img src="' . $logo . '" alt="' . t('Home') . '" /></a>';
    if (!empty($site_name) || !empty($site_slogan)) { 
      $out .= '<div id="name-and-slogan">';
      if (!empty($site_name)) $out .= '<h1 id="site-name"><a href="' . $front_page . '" title="' . t('Home') . '" rel="home">' . $site_name . '</a></h1>';
      if (!empty($site_slogan)) $out .= '<div id="site-slogan">' . $site_slogan . '</div>';
      $out .= '</div> <!-- /#name-and-slogan -->';
    }    
    $out .= '</div> <!-- /#logo-title -->';
    return $out;
  }
}

/**
 * Search Box
 */
function om_search_box($search_box) {
  if (!empty($search_box)) return '<div id="search-box">' . $search_box . '</div>';
}

/**
 * Primary, Secondary Menus
 */
function om_menu($menu_name = NULL, $menu = NULL, $menu_tree = NULL) {
  if (!empty($menu)) return '<div id="menubar-' . $menu_name . '" class="menubar">' . $menu_tree . '</div>';
}
/**
 * Overriding the menu item behavior
 *
 */
function om_menu_item($link, $has_children, $menu = '', $in_active_trail = FALSE, $extra_class = NULL) {
  $class = ($menu ? 'expanded' : ($has_children ? 'collapsed' : 'leaf'));
  
  if (!empty($extra_class)) $class .= ' ' . $extra_class;

  if ($in_active_trail) $class .= ' active-trail';
  
  return '<li class="' . $class . ' ' . $link . $menu . "</li>\n";  
}

/**
 * Adding menu id to li tag classes and not to a tag
 *
 */
function om_menu_item_link($link) {
  if (empty($link['localized_options'])) $link['localized_options'] = array();

  // OM Tools integration  
  if (module_exists('om_tools')) {
    $om_tools_values = variable_get('om_tools', '');  
    if (isset($om_tools_values['menu']) && ($om_tools_values['menu']['menu_classes_switch'] == 1)) {  
      $class = $om_tools_values['menu']['menu_classes_' . $link['mlid']]; 
      $link['localized_options']['attributes']['class'] = $class;
    }
  }
  //dsm($link);
  if(isset($link['tab_root'])) {
    //This works for local tabs
    return l($link['title'], $link['href'], $link['localized_options']);
  }
  else {
    //This is for normal menus
    return 'menu-' . $link['mlid'] . '">' . l($link['title'], $link['href'], $link['localized_options']);
  }
}


/**
 * Process all region formats
 *
 * @Legacy - soon will be deleted 
 * 
 */ 
function om_region($region_name = NULL, $region = NULL, $classes = NULL, $region_inner = 0) {

  if ($region) { 
    $id           = preg_replace('/_/', '-', $region_name);
    
    $div_prefix = '<div id="' . $id . '" class="region region-' . $id . ' ' . $classes . '">'; 
    $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $id. ' -->'; 

    if ($region_inner == 1) { 
      $div_prefix .= '<div id="' . $id . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $id . '-inner --></div><!-- /#' . $id . ' -->'; 
    }
    return $div_prefix . $region . $div_suffix;
  }
}

/**
 * Breadcrumbs
 */
function om_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) return '<div id="breadcrumb">' . implode(' » ', $breadcrumb) . '</div>'; 
}


/**
 * Process all content elements
 */
function om_content_elements($mission = NULL, $tabs = NULL, $title = NULL) {
  $out = '';
  if (!empty($mission)) $out .= '<div id="mission">' . $mission .'</div>'; 
  if (!empty($tabs))    $out .= '<div class="tabs">' . $tabs .'</div>'; 
  if (!empty($title))   $out .= '<h1 class="title" id="page-title">' . preg_replace('/\[break\]/', '<br />', $title) . '</h1>'; 
  return $out;
}

/**
 * Converts a string to a suitable html ID attribute.
 *
 * http://www.w3.org/TR/html4/struct/global.html#h-7.5.2 specifies what makes a
 * valid ID attribute in HTML. This function:
 *
 * - Ensure an ID starts with an alpha character by optionally adding an 'id'.
 * - Replaces any character except alphanumeric characters with dashes.
 * - Converts entire string to lowercase.
 *
 * @param $string
 *   The string
 * @return
 *   The converted string
 */
function om_id_safe($string) {
  // Replace with dashes anything that isn't A-Z, numbers, dashes, or underscores.
  return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
}


/**
 * Process regions.php provided on theme
 *
 */
function om_regions_process_info($region = NULL, $properties = array()) {

  if ($region) { 
    $id      = $properties['id'];
    $classes = $properties['class'];
    $inner   = $properties['inner'];
    $top     = $properties['top'];
    $bottom  = $properties['bottom'];

    $div_top     = ($top) ? '<div class="region-top"><div class="region-top-left"></div><div class="region-top-right"></div></div>': '';
    $div_bottom  = ($bottom) ? '<div class="region-bottom"><div class="region-bottom-left"></div><div class="region-bottom-right"></div></div>': '';
        
    $div_prefix = '<div id="' . $id . '" class="region region-' . $id . ' ' . $classes . '">' . $div_top; 
    $div_suffix = '<div class="om-clearfix"></div>' . $div_bottom . '</div><!-- /#' . $id. ' -->'; 

    if ($inner) { 
      $div_prefix .= '<div id="' . $id . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="om-clearfix"></div></div>' . $div_bottom . '</div><!-- /#' . $id . '-inner --><!-- /#' . $id . ' -->'; 
    }

    return $div_prefix . $region . $div_suffix;
  }
}


/**
 * Get region files
 *
 */  
function om_regions_file_get($file_name = NULL, $type = 'css') {
  global $theme;
  global $theme_path;  
  if (file_exists($theme_path . '/' . $type . '/' . $file_name . '.' . $type)) {
    $function = 'drupal_add_' . $type;
    $function($theme_path . '/' . $type . '/' . $file_name . '.' . $type);
  } 
}


/**
 * Override or insert om variables into the templates.
 */
function om_preprocess_page(&$vars) {
  global $theme; 
  global $theme_path;     
  // Better processing of regions
  if (file_exists($theme_path . '/regions.php')) {
    include_once $theme_path . '/regions.php';

    $regions_system = $vars['page'];    
    $regions = om_regions_get_info();
    foreach ($regions as $region => $properties) {
      // this will just load non-empty regions
      if (isset($vars[$region]) && !empty($vars[$region])) {
        om_regions_file_get($region, 'css');
        om_regions_file_get($region, 'js');      
        $vars[$region . '_region'] = om_regions_process_info($vars[$region], $properties);
      }
      else {
        $vars[$region . '_region'] = '';
      }
    }
  }
  
  // OM Grid Guides
  $om_grid_buttons = '<div id="om-grid-guide-buttons"><div class="om-grid-title">OM 960 Grids</div>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-button" type="radio" id="om-grid-guide-button-disabled" class="form-radio" value="" /> Disabled</label>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-button" type="radio" id="om-grid-guide-button-12" class="form-radio" value="12" /> 12 Columns</label>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-button" type="radio" id="om-grid-guide-button-16" class="form-radio" value="16" /> 16 Columns</label>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-button" type="radio" id="om-grid-guide-button-24" class="form-radio" value="24" /> 24 Columns</label>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-overlay" type="checkbox" id="om-grid-guide-overlay" class="form-checkbox" value="1" /> Overlay</label>';
  $om_grid_buttons .= '<label><input name="om-grid-guide-info" type="checkbox" id="om-grid-guide-info" class="form-checkbox" value="1" /> Info</label>';
  $om_grid_buttons .= '</div>';
  
  if (user_access('administer')) {
    drupal_add_js(drupal_get_path('theme', 'om') . '/js/om_grids.js');
    $vars['closure'] .= $om_grid_buttons;
  }  
  // this is to add any new js
  $vars['styles'] = drupal_get_css();
  // this is to add any new js
  $vars['scripts'] = drupal_get_js();

  // for adaptive design based on browser width
  $vars['head'] .= '<meta name="viewport" content="initial-scale=1.0, width=device-width" />';
  $vars['head'] .= '<meta name="MobileOptimized" content="width">';
  $vars['head'] .= '<meta name="HandheldFriendly" content="true">';
  $vars['head'] .= '<meta name="apple-mobile-web-app-capable" content="yes">';
  $vars['head'] .= '<meta http-equiv="cleartype" content="on">';
  $vars['head'] .= '<meta http-equiv="X-UA-Compatible" content="IE=edge, chrome=1">';  
  $vars['head_title'] = preg_replace('/\[break\]/', '', $vars['head_title']);
  $vars['tabs2'] = menu_secondary_local_tasks();
  // Generate menu tree from source of primary links
  $vars['main_menu'] = $vars['primary_links'];
  $vars['secondary_menu'] = $vars['secondary_links'];
  //$vars['main_menu_tree'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
  //Override main_menu_tree variable use:
  $vars['main_menu_array']  = menu_tree_page_data('primary-links');
  //dsm($vars['main_menu_array']);

  // OM Maximenu integration  
  if (!isset($vars['main_menu_tree']) && empty($vars['main_menu_tree'])) $vars['main_menu_tree'] = menu_tree_output($vars['main_menu_array']);
  
  $vars['secondary_menu_tree'] = menu_tree(variable_get('menu_secondary_links_source', 'secondary-links'));

  // Hook into color.module
  if (module_exists('color')) _color_page_alter($vars); 
  
  date_default_timezone_set('UTC');
  $vars['closure'] .= '<div id="legal"><a href="http://www.drupal.org/project/om">OM Base Theme</a> ' . date('Y') . ' | V6.x-2.x | by <a href="http://www.danielhonrade.com">Daniel Honrade</a></div>';


  
  // recognize url aliases as file page templates, ex. page-title.tpl.php
  if (module_exists('path')) {
    $alias = drupal_get_path_alias(str_replace('/edit', '', $_GET['q']));
    if ($alias != $_GET['q']) {
      $template_filename = 'page';
      foreach (explode('/', $alias) as $path_part) {
        $template_filename = $template_filename . '-' . $path_part;
        $vars['template_files'][] = $template_filename;
      }
    }
  }
  // aggregate css files
  $preprocess_css = variable_get('preprocess_css', 0);
  $query_string = '?' . substr(variable_get('css_js_query_string', '0'), 0, 1);
  if (!$preprocess_css) {
    $styles = '';
    foreach ($vars['css'] as $media => $types) {
      $import = '';
      $counter = 0;
      foreach ($types as $files) {
        foreach ($files as $css => $preprocess) {
          $import .= '@import "'. base_path() . $css . $query_string .'";'."\n";
          $counter++;
          if ($counter == 15) {
            $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
            $import = '';
            $counter = 0;
          }
        }
      }
      if ($import) $styles .= "\n".'<style type="text/css" media="'. $media .'">'."\n". $import .'</style>';
    }
    if ($styles) $vars['styles'] = $styles;
  }
  
  // kill the old left & right sidebars effect on body classes
  $old_sidebars = array('no-sidebars', 'two-sidebars', 'one-sidebar', 'sidebar-left', 'sidebar-right');
  foreach ($old_sidebars as $old_sidebars_key => $old_sidebars_class) {
    $vars['body_classes'] = str_replace($old_sidebars_class, '', $vars['body_classes']);
  }

  // substitute $sidebar_left and $sidebar_right for $left and $right
  // Set up layout variable.
  $vars['layout'] = 'none';  
      
  if (!empty($vars['sidebar_first'])) $vars['layout'] = 'first';
  if (!empty($vars['sidebar_second'])) $vars['layout'] = ($vars['layout'] == 'first') ? 'both' : 'second';

  // Add information about the number of sidebars.
  if ($vars['layout'] == 'both') {
    $vars['body_classes'] .= ' two-sidebars';
  }
  elseif ($vars['layout'] == 'none') {
    $vars['body_classes'] .= ' no-sidebars';
  }
  else {
    $vars['body_classes'] .= ' one-sidebar sidebar-'. $vars['layout'];
  }
  
  // browser as body class
  $browser = om_browser_get();
  $vars['body_classes'] .= ' ' . om_id_safe('browser-' . $browser['browser']);
  $vars['body_classes'] .= ' ' . om_id_safe('browser-' . $browser['browser'] . '-' . $browser['version']);
    
	// This  functionality will soon be transferred to OM Tools
  if (!module_exists('om_tools')) {

    $classes = explode(' ', $vars['body_classes']);
    
    if (!$vars['is_front']) {
    
      // Add unique class for each page.
      $path = drupal_get_path_alias($_GET['q']);
      
      // path title
      $classes[] = om_id_safe('page-' . $path);
      
      // default section
      list($section) = explode('/', $path, 2);

      $arg = arg(); // get all arguments

      if ($arg[0] == 'node') {
      
        $node_type = isset($vars['node']->type) ? $vars['node']->type: ''; 
        			         
        if (($arg[1] == 'add') && isset($arg[2])) { // add node
          $section      = 'node-add';                    
          $page_type    = $arg[2];                     
          $page_type_op = $page_type . '-add';         
        }
        elseif (($arg[1] == 'add') && !isset($arg[2])) { // add any node
          $section      = 'node-add';               
          $page_type    = 'any';                    
          $page_type_op = $page_type . '-add';           
        }          
        elseif (is_numeric($arg[1]) && !isset($arg[2]) && empty($node_type)) { // not found
          $section      = 'page-not-found';              
          $page_type    = 'any';                    
          $page_type_op = $page_type . '-view';         
        }
        elseif (is_numeric($arg[1]) && !isset($arg[2])) { // view node
          // default $section                        
          $page_type    = $node_type;                  
          $page_type_op = $page_type . '-view';          
        }					
        elseif (is_numeric($arg[1]) && isset($arg[2])) { // has arg 2, like delete, edit, etc.
          $section      = 'node-' . $arg[2];               
          $page_type    = !empty($node_type) ? $node_type: 'any';                   
          $page_type_op = $page_type . '-' . $arg[2];          
        }    
        $classes[] = om_id_safe('content-type-' . $page_type);
        $classes[] = om_id_safe('content-type-' . $page_type_op);
      }
      $classes[] = om_id_safe('section-' . $section);
    }
    $vars['body_classes_array'] = $classes;
    $vars['body_classes'] = implode(' ', $classes); // Concatenate with spaces.	
  }
}

/**
 * Override or insert variables into the block templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("block" in this case.)
 */
function om_preprocess_block(&$vars, $hook) {
  $block = $vars['block'];
  $blocks = block_list($block->region);
  // Additional classes for blocks.
  $block_classes[] = 'block';
  $block_classes[] = 'block-' . $block->module;
  $block_classes[] = 'block-' . $vars['block_zebra'];
  
  $block_classes[] = 'block-' . $vars['block_id'];
  $block_classes[] = 'block-group-' . count($blocks);

  // Block Class Module
  if (module_exists('block_class')) $block_classes[] = block_class($block); 	

  // OM Tools Module
  if (module_exists('om_tools') && $vars['om_block_classes']) $block_classes[] = $vars['om_block_classes'];

  if ($vars['block_id'] == 1) $block_classes[] = 'block-first';
	if ($vars['block_id'] == count($blocks)) $block_classes[] = 'block-last';

	// Block Edit
  $vars['edit_block_array'] = array();
  $vars['edit_block'] = '';
  if (user_access('administer blocks')) {
    om_edit_block($vars, $hook);
    $block_classes[] = 'with-edit-block';
  }	
  // Aggregate block classes.
  $vars['block_classes'] = implode(' ', $block_classes);	
  //dsm($vars);
}


function om_edit_block(&$vars, $hook) {
  $block = $vars['block'];
  // Display 'edit block' for custom blocks.
  if ($block->module == 'block') {
    $vars['edit_block_array'][] = l( t('edit block'), 'admin/build/block/configure/' . $block->module . '/' . $block->delta,
      array(
        'attributes' => array(
          'title' => t('Edit this block\'s content.'),
          'class' => 'block-edit',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  // Display 'configure' for other blocks.
  else {
    $vars['edit_block_array'][] = l( t('configure'), 'admin/build/block/configure/' . $block->module . '/' . $block->delta,
      array(
        'attributes' => array(
          'title' => t('Configure ' . $block->subject),
          'class' => 'block-config',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  // Display 'edit view' for Views blocks.
  if ($block->module == 'views' && user_access('administer views')) {
    list($view_name, $view_block) = explode('-block', $block->delta);
    $vars['edit_block_array'][] = l( t('edit view'), 'admin/build/views/edit/' . $view_name,
      array(
        'attributes' => array(
          'title' => t('Edit this view.'),
          'class' => 'block-edit-view',
        ),
        'query' => drupal_get_destination(),
        'fragment' => 'views-tab-block' . $view_block,
        'html' => TRUE,
      )
    );
  }
  // Display 'edit menu' for Menu blocks.
  elseif (($block->module == 'menu' || ($block->module == 'user' && $block->delta == 1)) && user_access('administer menu')) {
    $menu_name = ($block->module == 'user') ? 'navigation' : $block->delta;
    $vars['edit_block_array'][] = l( t('edit menu'), 'admin/build/menu-customize/' . $menu_name,
      array(
        'attributes' => array(
          'title' => t('Edit this menu.'),
          'class' => 'block-edit-menu',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  // Display 'edit menu' for Menu block blocks.
  elseif ($block->module == 'menu_block' && user_access('administer menu')) {
    list($menu_name, ) = split(':', variable_get("menu_block_{$block->delta}_parent", 'navigation:0'));
    $vars['edit_block_array'][] = l( t('edit menu'), 'admin/build/menu-customize/' . $menu_name,
      array(
        'attributes' => array(
          'title' => t('Edit this menu.'),
          'class' => 'block-edit-menu',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  $vars['edit_block'] = '<div class="edit-block">' . implode(' ', $vars['edit_block_array']) . '</div>';
}


/**
 * Get Browsers Name and Version
 *
 */
function om_browser_get($agent = NULL) {
  // Default known browsers
  $known_browsers = array('msie', 'firefox', 'safari', 'webkit', 'opera', 'netscape', 'konqueror', 'gecko');
  $agent = strtolower($agent ? $agent : $_SERVER['HTTP_USER_AGENT']);
  $pattern = '#(?<browser>' . join('|', $known_browsers) . ')[/ ]+(?<version>[0-9]+(?:\.[0-9]+)?)#';
  if (!preg_match_all($pattern, $agent, $matches)) return array();
  $i = count($matches['browser'])-1;
  $out = array();
  $out['browser'] = $matches['browser'][$i];
  $out['version'] = $matches['version'][$i];  
  return $out;
}

 
/**
 * Generates IE CSS links for LTR and RTL languages.
 *
 */

function om_get_ie_styles($ie) {
  global $language;
  global $theme; 
  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . drupal_get_path('theme', $theme) . '/css/' . $ie . '.css" />';
  if ($language->direction == LANGUAGE_RTL) $iecss .= '<style type="text/css" media="all">@import "'. base_path() . drupal_get_path('theme', $theme) .'/css/ie-rtl.css";</style>';
  return $iecss;
}


